fn other_endpoint<G>(
network: G,
edge: G::EdgeRef,
vertex: G::NodeId,
) -> G::NodeIdwhere
G: NodeIndexable + IntoEdgeReferences,Expand description
Gets the other endpoint of graph edge, if any, otherwise panics.
fn other_endpoint<G>(
network: G,
edge: G::EdgeRef,
vertex: G::NodeId,
) -> G::NodeIdwhere
G: NodeIndexable + IntoEdgeReferences,Gets the other endpoint of graph edge, if any, otherwise panics.