fn find_augmenting_path<G>(
network: G,
source: G::NodeId,
destination: G::NodeId,
flows: &[G::EdgeWeight],
level_edges: &mut [Vec<G::EdgeRef>],
visited: &mut G::Map,
edge_to: &mut [Option<G::EdgeRef>],
) -> boolwhere
G: IntoEdges + NodeIndexable + EdgeIndexable + Visitable,
G::EdgeWeight: Sub<Output = G::EdgeWeight> + PositiveMeasure,Expand description
Makes a DFS to find an augmenting path from source to destination vertex
using previously computed edge_levels from level graph.
Returns a boolean indicating if an augmenting path to destination was found.