fn find_blocking_flow<G>(
network: G,
source: G::NodeId,
destination: G::NodeId,
flows: &mut [G::EdgeWeight],
level_edges: &mut [Vec<G::EdgeRef>],
visited: &mut G::Map,
) -> G::EdgeWeightwhere
G: NodeCount + IntoEdges + NodeIndexable + EdgeIndexable + Visitable,
G::EdgeWeight: Sub<Output = G::EdgeWeight> + PositiveMeasure,Expand description
Find blocking flow for current level graph by repeatingly finding augmenting paths in it.
Attach computed flows to flows and returns the total flow increase from
edges available in level_edges at this iteration.